==> gpstk-1.7.src.tar.gz: gpstk/lib/procframe/ComputePI.cpp <==
#pragma ident "$Id: ComputePI.cpp 1308 2008-07-22 20:01:04Z architest $"

/**
 * @file ComputePI.cpp
 * This class eases computing PI combination for GNSS data structures.
 */

//============================================================================
//
//  This file is part of GPSTk, the GPS Toolkit.
//
//  The GPSTk is free software; you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published
//  by the Free Software Foundation; either version 2.1 of the License, or
//  any later version.
//
//  The GPSTk is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with GPSTk; if not, write to the Free Software Foundation,
//  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Dagoberto Salazar - gAGE ( http://www.gage.es ). 2007, 2008
//
//============================================================================


#include "ComputePI.hpp"


namespace gpstk
{

      // Index initially assigned to this class
   int ComputePI::classIndex = 2350000;


      // Returns an index identifying this object.
   int ComputePI::getIndex() const
   { return index; }


      // Returns a string identifying this object.
   std::string ComputePI::getClassName() const
   { return "ComputePI"; }


      // Default constructor
   ComputePI::ComputePI()
   {
      type1 = TypeID::P1;
      type2 = TypeID::P2;
      resultType = TypeID::PI;
      setIndex();
   }


} // End of namespace gpstk

==> gpstk-2.0.src.tar.gz: gpstk/lib/procframe/ComputePI.cpp <==
#pragma ident "$Id: ComputePI.cpp 3140 2012-06-18 15:03:02Z susancummins $"

/**
 * @file ComputePI.cpp
 * This class eases computing PI combination for GNSS data structures.
 */

//============================================================================
//
//  This file is part of GPSTk, the GPS Toolkit.
//
//  The GPSTk is free software; you can redistribute it and/or modify
//  it under the terms of the GNU Lesser General Public License as published
//  by the Free Software Foundation; either version 2.1 of the License, or
//  any later version.
//
//  The GPSTk is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with GPSTk; if not, write to the Free Software Foundation,
//  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
//
//  Dagoberto Salazar - gAGE ( http://www.gage.es ). 2007, 2008, 2011
//
//============================================================================


#include "ComputePI.hpp"


namespace gpstk
{

      // Returns a string identifying this object.
   std::string ComputePI::getClassName() const
   { return "ComputePI"; }


      // Default constructor
   ComputePI::ComputePI()
   {
      type1 = TypeID::P1;
      type2 = TypeID::P2;
      resultType = TypeID::PI;
   }


} // End of namespace gpstk
